@@ -127,7 +127,7 @@ class WorkerServer(BaseServer):
             queue=self.amqp_queue,
             durable=False,
             exclusive=False,
-            auto_delete=False)
+            auto_delete=True)
         yield self.chan.queue_bind(
             queue=self.amqp_queue,
             exchange=self.amqp_exchange)
@@ -206,7 +206,7 @@ class WorkerServer(BaseServer):
             else:
                 # assign a temp uuid
                 uuid = UUID(bytes=msg.content.body).hex
-            self.chan.basic_ack(delivery_tag=job['delivery_tag'])
+            # self.chan.basic_ack(delivery_tag=job['delivery_tag'])
             d = self.callExposedFunction(
                 exposed_function["function"], 
                 kwargs, 
